# Configuration

Classes that control how `BasanosEngine` and `BasanosStream` behave.

## BasanosConfig

::: basanos.math.BasanosConfig

---

## CovarianceMode

::: basanos.math.CovarianceMode

---

## EwmaShrinkConfig

::: basanos.math.EwmaShrinkConfig

---

## SlidingWindowConfig

::: basanos.math.SlidingWindowConfig

---

## CovarianceConfig

::: basanos.math.CovarianceConfig
